(TeX-add-style-hook
 "references"
 (lambda ()
   (LaTeX-add-bibitems
    "saxon2021OpenSoftware"
    "fotheringham2017multiscale"
    "cortes2019OpensourceFramework"
    "rey_2021a"
    "rey2020VisualAnalytics"
    "rey2023GeographicData"
    "Akaike1974"
    "Anselin1988"
    "Anselin1996a"
    "Anselin1997"
    "Anselin2011"
    "Gaboardi2021"
    "Lumnitz2020"
    "Anselin95"
    "spopt2022"
    "Arraiz2010"
    "Assun_o_1999"
    "Belsley1980"
    "Benjamini:2001"
    "Bickenbach2003"
    "Breusch1979"
    "Castro:2006tz"
    "Christensen2005"
    "Dijkstra1959a"
    "Drukker2013"
    "Formby:2004fk"
    "Fotheringham2016"
    "Fotheringham:2017"
    "Getis_2010"
    "Greene2003"
    "Hubert_1981"
    "Ibe2009"
    "Jarque1980"
    "Jiang_2013"
    "Kang2018"
    "Kelejian1998"
    "Kelejian1999"
    "Kemeny1967"
    "Koenker1982"
    "Kullback1962"
    "Lee2001"
    "Okabe2001"
    "Ord_2010"
    "Press2007"
    "Reardon2008"
    "Rey2001"
    "Rey2004a"
    "Rey2011"
    "Rey2014"
    "Rey2014a"
    "Rey2016"
    "Rey2016a"
    "Rey_2013_sea"
    "Rey_2016"
    "Schwarz1978"
    "Silva:2016"
    "Slocum_2009"
    "VanLieshout1996"
    "White1980"
    "allen2015more"
    "anselin2006geoda"
    "anselin2014ModernSpatial"
    "article-minimal"
    "belsey_regression_1980"
    "brunsdon2008geographically"
    "brunsdon:1999"
    "carrington1997measuring"
    "cliff81"
    "duque18"
    "fleischmann_2019"
    "folch2016centralization"
    "fotheringham1999local"
    "fotheringham_geographically_2002"
    "harris_use_2010"
    "hong2014implementing"
    "hong2014measuring"
    "isard1967methods"
    "massey1988dimensions"
    "morgan1983distance"
    "morrill1991measure"
    "nakaya2005geographically"
    "oshan_comparison_2017"
    "osullivanwong2007surface"
    "pysal2007"
    "reardon1998measures"
    "reardon2002measures"
    "reardon2004measures"
    "rey2014PythonSpatial"
    "rey2019pysal"
    "rey2022PySALEcosystem"
    "rey_comparative_2015"
    "rey_interregional_2010"
    "roberto2015divergence"
    "sakoda1981generalized"
    "simpson1949measurement"
    "theil1972statistical"
    "tivadar2019oasisr"
    "wheeler_diagnostic_2007"
    "wong1993spatial"
    "yu:2019"))
 '(or :bibtex :latex))

